@@ -3,7 +3,9 @@
  * st-scroll-bar.c: Scroll bar actor
  *
  * Copyright 2008 OpenedHand
- * Copyright 2009 Intel Corporation.
+ * Copyright 2008, 2009 Intel Corporation.
+ * Copyright 2009, 2010 Red Hat, Inc.
+ * Copyright 2010 Maxim Ermilov
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms and conditions of the GNU Lesser General Public License,
@@ -15,12 +17,7 @@
  * more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * Written by: Chris Lord <chris@openedhand.com>
- * Port to St by: Robert Staudinger <robsta@openedhand.com>
- *
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -113,6 +110,8 @@ handle_button_press_event_cb (ClutterActor       *actor,
                               ClutterButtonEvent *event,
                               StScrollBar        *bar);
 
+static void stop_scrolling (StScrollBar *bar);
+
 static void
 st_scroll_bar_get_property (GObject    *gobject,
                             guint       prop_id,
@@ -274,6 +273,8 @@ st_scroll_bar_unmap (ClutterActor *actor)
 
   CLUTTER_ACTOR_CLASS (st_scroll_bar_parent_class)->unmap (actor);
 
+  stop_scrolling (ST_SCROLL_BAR (actor));
+
   clutter_actor_unmap (priv->bw_stepper);
   clutter_actor_unmap (priv->fw_stepper);
   clutter_actor_unmap (priv->trough);
@@ -646,13 +647,11 @@ st_scroll_bar_constructor (GType                  type,
   GObjectClass *gobject_class;
   GObject *obj;
   StScrollBar *bar;
-  StScrollBarPrivate *priv;
 
   gobject_class = G_OBJECT_CLASS (st_scroll_bar_parent_class);
   obj = gobject_class->constructor (type, n_properties, properties);
 
   bar  = ST_SCROLL_BAR (obj);
-  priv = ST_SCROLL_BAR_GET_PRIVATE (bar);
 
   g_signal_connect (bar, "notify::reactive",
                     G_CALLBACK (bar_reactive_notify_cb), NULL);
@@ -811,6 +810,22 @@ move_slider (StScrollBar *bar,
   st_adjustment_set_value (priv->adjustment, position);
 }
 
+static void
+stop_scrolling (StScrollBar *bar)
+{
+  ClutterActor *stage;
+
+  if (!bar->priv->capture_handler)
+    return;
+
+  stage = clutter_actor_get_stage (bar->priv->trough);
+  g_signal_handler_disconnect (stage, bar->priv->capture_handler);
+  bar->priv->capture_handler = 0;
+
+  clutter_set_motion_events_enabled (TRUE);
+  g_signal_emit (bar, signals[SCROLL_STOP], 0);
+}
+
 static gboolean
 handle_capture_event_cb (ClutterActor *trough,
                          ClutterEvent *event,
@@ -827,19 +842,11 @@ handle_capture_event_cb (ClutterActor *trough,
     {
       ClutterActor *stage, *target;
 
-      stage = clutter_actor_get_stage(bar->priv->trough);
-
-      if (bar->priv->capture_handler)
-        {
-          g_signal_handler_disconnect (stage, bar->priv->capture_handler);
-          bar->priv->capture_handler = 0;
-        }
-
-      clutter_set_motion_events_enabled (TRUE);
-      g_signal_emit (bar, signals[SCROLL_STOP], 0);
+      stop_scrolling (bar);
 
       /* check if the mouse pointer has left the handle during the drag and
        * remove the hover state if it has */
+      stage = clutter_actor_get_stage (bar->priv->trough);
       target = clutter_stage_get_actor_at_pos ((ClutterStage*) stage,
                                                CLUTTER_PICK_REACTIVE,
                                                ((ClutterButtonEvent*) event)->x,
@@ -848,8 +855,6 @@ handle_capture_event_cb (ClutterActor *trough,
         {
           st_widget_remove_style_pseudo_class ((StWidget*) bar->priv->handle, "hover");
         }
-
-
     }
 
   return TRUE;
